@@ -65,6 +65,15 @@ class Queue:
         except Exception as ex:
             print("Error, %s" %ex, end=', ')
 
+    def find(self, data):
+        count = 0
+        tmp = self.__front
+        while tmp is not None:
+            if tmp.data = data:
+                count += 1
+            tmp = tmp.next
+        return count
+
     def reverse(self):
         stck = stack.Stack()
         while not self.empty():
